function [ cleDrawDat ] = cleBox(x,y,width,lngth,varargin)
%cleBox    - Draw box.
%
%   cleDrawDat = cleBox(x, y, width, length, angle)
%       x                - Box x centre position.
%       y                - Box y centre position.
%       width            - Box width.
%       length           - Box length.
%       angle            - Optional box rotation angle around centre position.
%
%       cleDrawDat       - Optional output structure for further editing.
%                          If not used, data is directly writen to CleWin.

global CleWin;

if (~isnumeric(x) | ~isnumeric(y) | ~isnumeric(lngth) | ~isnumeric(width) | ...
     length(x)~=1 | length(y)~=1 | length(lngth)~=1 | length(width)~=1 )
    error('CleWin:cleBox:InputError', ...
          'Incorrect input parameter(s).');
end;

if nargin>4
 if (~isnumeric(varargin{1}) |  length(varargin{1})~=1 )
    error('CleWin:cleBox:InputError', ...
          'Incorrect input parameter(s).');  
 end;
end;

%------------------------------------------------------------

cleDrawDat=cleEmpty();
cleDrawDat.cleBox{1}.length=lngth;
cleDrawDat.cleBox{1}.width=width;
cleDrawDat.cleBox{1}.x=x;
cleDrawDat.cleBox{1}.y=y;
cleDrawDat.cleBox{1}.layer=CleWin.layer;


if nargin>4,
 cleDrawDat.cleBox{1}.angle=varargin{1};
else
 cleDrawDat.cleBox{1}.angle=0;
end;

if nargout < 1,
 cleDraw(cleDrawDat)
end;

%------------------------------------------------------------

