function [ cleDrawDatOut ] = cleMoveLayer(cleDrawDatIn,targetLayerIn,varargin)
%cleMoveLayer    - Move layers in cleDrawDat structure.
%
%   cleDrawDat = cleMoveLayer(cleDrawDat, targetLayer)
%       targetLayer     - Move all layers in cleDrawDat to targetLayer.
%
%   cleDrawDat = cleMoveLayer(cleDrawDat, targetLayer, sourceLayer)
%       targetLayer     - Move sourceLayer to targetLayer in cleDrawDat.
%
%   cleDrawDat = cleMoveLayer(cleDrawDat, targetLayer, {sourceLayer1 sourceLayer2})
%       targetLayer     - Move sourceLayers to targetLayer in cleDrawDat.
%
%   cleDrawDat = cleMoveLayer(cleDrawDat, {targetLayer1 targetLayer2}, {sourceLayer1 sourceLayer2})
%       targetLayer     - Move sourceLayers to targetLayers in cleDrawDat.



if (isstruct(cleDrawDatIn) & ~iscell(targetLayerIn) & (length(targetLayerIn)==1 | isstr(targetLayerIn)) & nargin==2),
 sourceLayerList=[];
 targetLayerList=cleCoreLayerIndex(targetLayerIn);
elseif (isstruct(cleDrawDatIn) & nargin==3)
 if ( (length(targetLayerIn)==1 | isstr(targetLayerIn)) & ~iscell(varargin{1}) & (length(varargin{1})==1 | isstr(varargin{1})) )
  sourceLayerList=cleCoreLayerIndex(varargin{1});
  targetLayerList=cleCoreLayerIndex(targetLayerIn);
 elseif ( (length(targetLayerIn)==1 | isstr(targetLayerIn)) & iscell(varargin{1}) )
  sourceLayerList=[];
  for n=1:length(varargin{1})
   sourceLayerList=[sourceLayerList cleCoreLayerIndex(varargin{1}{n})];
  end;
  targetLayerList=cleCoreLayerIndex(targetLayerIn);
 elseif ( iscell(targetLayerIn) & iscell(varargin{1}) & length(targetLayerIn)==length(varargin{1}))
  for n=1:length(varargin{1})
   sourceLayerList(n,1)=cleCoreLayerIndex(varargin{1}{n});
  end;
  targetLayerList=[];
  for n=1:length(targetLayerIn)
   targetLayerList=[targetLayerList cleCoreLayerIndex(targetLayerIn{n})];
  end;
 else
  error('CleWin:cleMoveLayer:InputError', ...
        'Incorrect input parameter(s).');
 end;
else
 error('CleWin:cleMoveLayer:InputError', ...
       'Incorrect input parameter(s).');
end;


cleDrawDatOut=cleDrawDatIn;


for n=1:length(targetLayerList),

 %------------------------------------------------------------
 for k=1:length(cleDrawDatIn.cleCircle),
  if (isempty(sourceLayerList))
   cleDrawDatOut.cleCircle{k}.layer=targetLayerList(n);
  elseif (~isempty(find(sourceLayerList(n,:)==cleDrawDatIn.cleCircle{k}.layer)))
   cleDrawDatOut.cleCircle{k}.layer=targetLayerList(n);
  end;
 end;
 %------------------------------------------------------------

 %------------------------------------------------------------
 for k=1:length(cleDrawDatIn.cleBox),
  if (isempty(sourceLayerList))
   cleDrawDatOut.cleBox{k}.layer=targetLayerList(n);
  elseif (~isempty(find(sourceLayerList(n,:)==cleDrawDatIn.cleBox{k}.layer)))
   cleDrawDatOut.cleBox{k}.layer=targetLayerList(n);
  end;
 end;
 %------------------------------------------------------------

 %------------------------------------------------------------
 for k=1:length(cleDrawDatIn.clePolygon),
  if (isempty(sourceLayerList))
   cleDrawDatOut.clePolygon{k}.layer=targetLayerList(n);
  elseif (~isempty(find(sourceLayerList(n,:)==cleDrawDatIn.clePolygon{k}.layer)))
   cleDrawDatOut.clePolygon{k}.layer=targetLayerList(n);
  end;
 end;
 %------------------------------------------------------------

 %------------------------------------------------------------
 for k=1:length(cleDrawDatIn.cleWire),
  if (isempty(sourceLayerList))
   cleDrawDatOut.cleWire{k}.layer=targetLayerList(n);
  elseif (~isempty(find(sourceLayerList(n,:)==cleDrawDatIn.cleWire{k}.layer)))
   cleDrawDatOut.cleWire{k}.layer=targetLayerList(n);
  end;
 end;
 %------------------------------------------------------------

 %------------------------------------------------------------
 for k=1:length(cleDrawDatIn.cleRing),
  if (isempty(sourceLayerList))
   cleDrawDatOut.cleRing{k}.layer=targetLayerList(n);
  elseif (~isempty(find(sourceLayerList(n,:)==cleDrawDatIn.cleRing{k}.layer)))
   cleDrawDatOut.cleRing{k}.layer=targetLayerList(n);
  end;
 end;
 %------------------------------------------------------------

 %------------------------------------------------------------
 for k=1:length(cleDrawDatIn.cleText),
  if (isempty(sourceLayerList))
   cleDrawDatOut.cleText{k}.layer=targetLayerList(n);
  elseif (~isempty(find(sourceLayerList(n,:)==cleDrawDatIn.cleText{k}.layer)))
   cleDrawDatOut.cleText{k}.layer=targetLayerList(n);
  end;
 end;
 %------------------------------------------------------------

end;



%------------------------------------------------------------
if nargout < 1,
 cleDraw(cleDrawDatOut);
end;
