function [ cleDrawDat ] = cleTextPrintf(x,y,angle,mirror,scale,format,varargin)
%clePrintf    - Print formatted text.
%
%   [cleDrawDat] = cleTextPrintf(x, y, typeFace, scale, alignment, format, ...)
%       x           - Text x position.
%       y           - Text y position.
%       angle       - Rotation angle.
%	mirror      - Leonardo script.
%       scale       - Font relative scale to text height.
%       format      - String containing C language conversion
%                     specifications.
%    
%       cleDrawDat  - Optional output structure for further editing.
%                     If not used, data is directly writen to CleWin.

global CleWin;

if (~isnumeric(x) | ~isnumeric(y) | ~isnumeric(scale) | ~isnumeric(angle) | ~islogical(mirror) |...
    ~isstr(format) | length(x)~=1 | length(y)~=1 | length(scale)~=1 | length(angle)~=1 | length(mirror)~=2 )
    error('CleWin:cleTextPrintf:InputError', ...
          'Incorrect input parameter(s).');
end;

%------------------------------------------------------------
cleDrawDat=cleEmpty();
cleDrawDat.cleText{1}.x=x;
cleDrawDat.cleText{1}.y=y;
cleDrawDat.cleText{1}.scale=scale;
cleDrawDat.cleText{1}.angle=angle;
cleDrawDat.cleText{1}.mirror=mirror;
cleDrawDat.cleText{1}.textString=sprintf(format,varargin{:});
cleDrawDat.cleText{1}.layer=CleWin.layer;

if nargout < 1,
 cleDraw(cleDrawDat);
end;

%------------------------------------------------------------